Index: trunk/VUT/GtpVisibilityPreprocessor/src/ViewCellBsp.cpp
===================================================================
--- trunk/VUT/GtpVisibilityPreprocessor/src/ViewCellBsp.cpp	(revision 202)
+++ trunk/VUT/GtpVisibilityPreprocessor/src/ViewCellBsp.cpp	(revision 221)
@@ -8,7 +8,7 @@
 //namespace GtpVisibilityPreprocessor {
 /****************************************************************/
 /*                  class BSPNode implementation                */
 /****************************************************************/
-bool BSPNode::IsRoot() const 
+bool BspNode::IsRoot() const 
 {
 	return mParent == NULL;
@@ -16,13 +16,13 @@
 
 /****************************************************************/
 /*              class BSPInterior implementation                */
 /****************************************************************/
 
-bool BSPInterior::IsLeaf() const
+bool BspInterior::IsLeaf() const
 { 
 	return false; 
 }
 
-void BSPInterior::ReplaceChildLink(BSPNode *oldChild, BSPNode *newChild) 
+void BspInterior::ReplaceChildLink(BspNode *oldChild, BspNode *newChild) 
 {
 	if (mBack == oldChild)
@@ -36,5 +36,5 @@
 }
 
-void BSPInterior::SetupChildLinks(BSPNode *b, BSPNode *f) 
+void BspInterior::SetupChildLinks(BspNode *b, BspNode *f) 
 {
     mBack = b;
@@ -43,12 +43,12 @@
 
 /****************************************************************/
 /*                  class BSPLeaf implementation                */
 /****************************************************************/
 
-BSPLeaf::BSPLeaf(ViewCell *viewCell): mViewCell(viewCell) 
+BspLeaf::BspLeaf(ViewCell *viewCell): mViewCell(viewCell) 
 {
 }
 
-bool BSPLeaf::IsLeaf() const 
+bool BspLeaf::IsLeaf() const 
 { 
 	return true; 
@@ -56,19 +56,19 @@
 
 /****************************************************************/
 /*                  class BSPTree implementation                */
 /****************************************************************/
 
-BSPTree::BSPTree(ViewCell *cell) 
+BspTree::BspTree(ViewCell *cell) 
 {
 	mRootCell = cell;
-	mRoot = new BSPLeaf(mRootCell);
+	mRoot = new BspLeaf(mRootCell);
 }
 
   
-void BSPTree::Subdivide()
+void BspTree::Subdivide()
 {
-	BSPNode *currentNode = mRoot;
+	BspNode *currentNode = mRoot;
   
-	std::stack<BSPTraversalData> tStack;
+	std::stack<BspTraversalData> tStack;
 	//  stack<STraversalData> tStack;
 
@@ -77,5 +77,5 @@
 	while (!tStack.empty()) 
 	{
-	    BSPTraversalData data = tStack.top();
+	    BspTraversalData data = tStack.top();
 	    tStack.pop();
     
@@ -83,5 +83,5 @@
 		Mesh frontPolys;
 
-		BSPNode *node = SubdivideNode(dynamic_cast<BSPLeaf *>(data.mNode),
+		BspNode *node = SubdivideNode(dynamic_cast<BspLeaf *>(data.mNode),
 									  data.mParent,
 									  &data.mViewCell,
@@ -92,21 +92,21 @@
 		if (!node->IsLeaf())
 		{
-			BSPInterior *interior = dynamic_cast<BSPInterior *>(node);
+			BspInterior *interior = dynamic_cast<BspInterior *>(node);
 
 			// push the children on the stack
 			if (interior->GetBack())
-				tStack.push(BSPTraversalData(interior->GetBack(), interior, backPolys, data.mDepth+1));
+				tStack.push(BspTraversalData(interior->GetBack(), interior, backPolys, data.mDepth+1));
 			if (interior->GetFront())
-				tStack.push(BSPTraversalData(interior->GetFront(), interior, frontPolys, data.mDepth+1));
+				tStack.push(BspTraversalData(interior->GetFront(), interior, frontPolys, data.mDepth+1));
 		}
 	}
 }
 
-Plane3 *BSPTree::SelectPlane(Mesh *viewcell)
+Plane3 *BspTree::SelectPlane(Mesh *viewcell)
 {
 	return &viewcell->GetFacePlane(0);
 }
 
-BSPNode *BSPTree::SubdivideNode(BSPLeaf *leaf, BSPInterior *parent, 
+BspNode *BspTree::SubdivideNode(BspLeaf *leaf, BspInterior *parent, 
 								Mesh *viewCell, const int depth, 
 								Mesh &frontPolys, Mesh &backPolys)
@@ -119,5 +119,5 @@
 	// add the new nodes to the tree + select subdivision plane
 	Plane3 *plane = SelectPlane(viewCell);
-	BSPInterior *node = new BSPInterior(*plane); // ERROR!!
+	BspInterior *node = new BspInterior(*plane); // ERROR!!
   
 
@@ -128,6 +128,6 @@
 	}
   
-	BSPLeaf *back = new BSPLeaf(mRootCell);
-	BSPLeaf *front = new BSPLeaf(mRootCell);
+	BspLeaf *back = new BspLeaf(mRootCell);
+	BspLeaf *front = new BspLeaf(mRootCell);
 
 	// replace a link from node's parent
@@ -8,7 +8,7 @@
 //namespace GtpVisibilityPreprocessor {
 /****************************************************************/
-/*                  class BSPNode implementation                */
+/*                  class BspNode implementation                */
 /****************************************************************/
@@ -16,13 +16,13 @@
 
 /****************************************************************/
-/*              class BSPInterior implementation                */
+/*              class BspInterior implementation                */
 /****************************************************************/
 
@@ -43,12 +43,12 @@
 
 /****************************************************************/
-/*                  class BSPLeaf implementation                */
+/*                  class BspLeaf implementation                */
 /****************************************************************/
 
@@ -56,19 +56,19 @@
 
 /****************************************************************/
-/*                  class BSPTree implementation                */
+/*                  class BspTree implementation                */
 /****************************************************************/
 
